==> bea_flutter_package-1.2.0.tar.gz: lib/bea_services/utils/crud_utils.dart <==
import 'package:flutter/widgets.dart';

class CRUDUtils{

 static String getSortingString(List<BEASorting> sortingList){
   String sorting = "";

   if(sortingList == null){return sorting;}

   String comma = sortingList.length > 1 ? "," : "";

   for(BEASorting bs in sortingList){
     sorting += "${bs.property} ${getSortingOptions(bs.sortinOptions)}$comma ";
   }

   return sorting;
 }

 static String getBEAFilter(List<BEAGenericFilter> genericFilterList){

   String filter = "";

   if(genericFilterList == null)return filter;

   int index = 0;
   for(BEAGenericFilter bgf in genericFilterList){

     index++;

     LogicalOperators lop = bgf.logicalOperators;
     if(lop == null){
       lop = LogicalOperators.AND;
     }
     String strLop = index == genericFilterList.length ? "" : ',"${getOperatorOptions(lop)}",';

     if(bgf.filter.runtimeType == BEAFilter){
       filter += '${_getSingleFilter(bgf.filter)}';
       filter += '$strLop';
     }else if(bgf.filter.runtimeType == (List<BEAGenericFilter<dynamic>>()).runtimeType){
       filter += getBEAFilter(bgf.filter);
       filter += '$strLop';
     }else{
       throw Exception("Unknown Type of filter");
     }
   }

   return "[$filter]";
 }

 static String _getSingleFilter(BEAFilter bf){
   String filter = "";
   if(bf == null)return filter;
   filter += '["${bf.property}",';
   filter += '"${getFilterOption(bf.filterOperators)}",';
   filter += '"${bf.value.toString()}"]';
   return filter;
 }

 static String getFilterOption(FilterOperators filterOperators){
   switch (filterOperators) {
     case FilterOperators.CONTAINS:
       return "contains";
     case FilterOperators.GREATER_THAN:
       return ">";
     case FilterOperators.SMALLER_THAN:
       return "<";
     case FilterOperators.SMALLER_EQUALS_THAN:
       return "<=";
     case FilterOperators.GREATER_EQUALS_THAN:
       return ">=";
     case FilterOperators.NOT_CONTAINS:
       return "notcontains";
     case FilterOperators.EQUALS:
       return "=";
     case FilterOperators.NOT_EQUALS:
       return "<>";
     case FilterOperators.STARTS_WITH:
       return "startswith";
     case FilterOperators.ENDS_WITH:
       return "endswith";
     default:
       return "=";
   }
 }

 static String getOperatorOptions(LogicalOperators logicalOperators){
   switch (logicalOperators) {
     case LogicalOperators.AND:
       return "and";
     case LogicalOperators.OR:
       return "or";
     default:
       return "and";
   }
 }

 static String getSortingOptions(SortinOptions sortinOptions){
   switch (sortinOptions) {
     case SortinOptions.DESC:
       return "desc";
     case SortinOptions.ASC:
       return "asc";
     default:
       return "asc";
   }
 }

}

enum SortinOptions {
  ASC,
  DESC
}

enum FilterOperators {
  GREATER_THAN,
  SMALLER_THAN,
  GREATER_EQUALS_THAN,
  SMALLER_EQUALS_THAN,
  CONTAINS,
  NOT_CONTAINS,
  EQUALS,
  NOT_EQUALS,
  STARTS_WITH,
  ENDS_WITH
}

enum LogicalOperators {
  AND,
  OR
}

class BEASorting{
  final String property;
  final SortinOptions sortinOptions;

  BEASorting({this.property, this.sortinOptions});
}

class BEAGenericFilter<BEAGeneric>{
  final BEAGeneric filter;
  final LogicalOperators logicalOperators;

  BEAGenericFilter({@required this.filter, this.logicalOperators});
}

class BEAFilter{
  final String property;
  final FilterOperators filterOperators;
  final dynamic value;

  BEAFilter({this.property, this.filterOperators, this.value});
}

==> bea_flutter_package-2.0.0.tar.gz: lib/bea_services/utils/crud_utils.dart <==
class CRUDUtils{

 static String getSortingString(List<BEASorting>? sortingList){
   String sorting = "";

   if(sortingList == null){return sorting;}

   String comma = sortingList.length > 1 ? "," : "";

   for(BEASorting bs in sortingList){
     sorting += "${bs.property} ${getSortingOptions(bs.sortinOptions)}$comma ";
   }

   return sorting;
 }

 static String getBEAFilter(List<BEAGenericFilter>? genericFilterList){

   String filter = "";

   if(genericFilterList == null)return filter;

   int index = 0;
   for(BEAGenericFilter bgf in genericFilterList){

     index++;

     LogicalOperators? lop = bgf.logicalOperators;
     if(lop == null){
       lop = LogicalOperators.AND;
     }
     String strLop = index == genericFilterList.length ? "" : ',"${getOperatorOptions(lop)}",';

     if(bgf.filter.runtimeType == BEAFilter){
       filter += '${_getSingleFilter(bgf.filter)}';
       filter += '$strLop';
     }else if(bgf.filter.runtimeType == (List.filled(0, BEAGenericFilter)).runtimeType){
       filter += getBEAFilter(bgf.filter);
       filter += '$strLop';
     }else{
       throw Exception("Unknown Type of filter");
     }
   }

   return "[$filter]";
 }

 static String _getSingleFilter(BEAFilter? bf){
   String filter = "";
   if(bf == null)return filter;
   filter += '["${bf.property}",';
   filter += '"${getFilterOption(bf.filterOperators)}",';
   filter += '"${bf.value.toString()}"]';
   return filter;
 }

 static String getFilterOption(FilterOperators? filterOperators){
   switch (filterOperators) {
     case FilterOperators.CONTAINS:
       return "contains";
     case FilterOperators.GREATER_THAN:
       return ">";
     case FilterOperators.SMALLER_THAN:
       return "<";
     case FilterOperators.SMALLER_EQUALS_THAN:
       return "<=";
     case FilterOperators.GREATER_EQUALS_THAN:
       return ">=";
     case FilterOperators.NOT_CONTAINS:
       return "notcontains";
     case FilterOperators.EQUALS:
       return "=";
     case FilterOperators.NOT_EQUALS:
       return "<>";
     case FilterOperators.STARTS_WITH:
       return "startswith";
     case FilterOperators.ENDS_WITH:
       return "endswith";
     default:
       return "=";
   }
 }

 static String getOperatorOptions(LogicalOperators logicalOperators){
   switch (logicalOperators) {
     case LogicalOperators.AND:
       return "and";
     case LogicalOperators.OR:
       return "or";
     default:
       return "and";
   }
 }

 static String getSortingOptions(SortinOptions? sortinOptions){
   switch (sortinOptions) {
     case SortinOptions.DESC:
       return "desc";
     case SortinOptions.ASC:
       return "asc";
     default:
       return "asc";
   }
 }

}

enum SortinOptions {
  ASC,
  DESC
}

enum FilterOperators {
  GREATER_THAN,
  SMALLER_THAN,
  GREATER_EQUALS_THAN,
  SMALLER_EQUALS_THAN,
  CONTAINS,
  NOT_CONTAINS,
  EQUALS,
  NOT_EQUALS,
  STARTS_WITH,
  ENDS_WITH
}

enum LogicalOperators {
  AND,
  OR
}

class BEASorting{
  final String? property;
  final SortinOptions? sortinOptions;

  BEASorting({this.property, this.sortinOptions});
}

class BEAGenericFilter<BEAGeneric>{
  final BEAGeneric filter;
  final LogicalOperators? logicalOperators;

  BEAGenericFilter({required this.filter, this.logicalOperators});
}

class BEAFilter{
  final String? property;
  final FilterOperators? filterOperators;
  final dynamic value;

  BEAFilter({this.property, this.filterOperators, this.value});
}
